summaryrefslogtreecommitdiff
path: root/thirdparty/harfbuzz/src/hb-ft.h
diff options
context:
space:
mode:
authorbruvzg <7645683+bruvzg@users.noreply.github.com>2022-07-04 09:11:15 +0300
committerbruvzg <7645683+bruvzg@users.noreply.github.com>2022-07-04 09:12:19 +0300
commit6c27d9d6244303754e111eccc7c1a42df5b9bca1 (patch)
treecddd5118a33a54620edfbe46545ae4872d74e81c /thirdparty/harfbuzz/src/hb-ft.h
parent41fdddb1f8132dcba8256a145de44da5df3155b2 (diff)
HarfBuzz: Update to version 4.4.1
Diffstat (limited to 'thirdparty/harfbuzz/src/hb-ft.h')
-rw-r--r--thirdparty/harfbuzz/src/hb-ft.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/thirdparty/harfbuzz/src/hb-ft.h b/thirdparty/harfbuzz/src/hb-ft.h
index bf07115ab9..6a8a7abe8c 100644
--- a/thirdparty/harfbuzz/src/hb-ft.h
+++ b/thirdparty/harfbuzz/src/hb-ft.h
@@ -122,10 +122,17 @@ hb_ft_font_set_load_flags (hb_font_t *font, int load_flags);
HB_EXTERN int
hb_ft_font_get_load_flags (hb_font_t *font);
/* Call when size or variations settings on underlying FT_Face change. */
HB_EXTERN void
hb_ft_font_changed (hb_font_t *font);
+/* Call when size or variations settings on underlying hb_font_t may have
+ * changed, and you want to update the FT_Face from it. This call is fast
+ * if nothing changed on hb_font_t. Returns true if changed. */
+HB_EXTERN hb_bool_t
+hb_ft_hb_font_changed (hb_font_t *font);
+
/* Makes an hb_font_t use FreeType internally to implement font functions.
* Note: this internally creates an FT_Face. Use it when you create your
* hb_face_t using hb_face_create(). */
@@ -122,10 +122,17 @@ hb_ft_font_set_load_flags (hb_font_t *font, int load_flags);
HB_EXTERN int
hb_ft_font_get_load_flags (hb_font_t *font);
-/* Call when size or variations settings on underlying FT_Face change. */
+/* Call when size or variations settings on underlying FT_Face changed,
+ * and you want to update the hb_font_t from it. */
HB_EXTERN void
hb_ft_font_changed (hb_font_t *font);